@@ -18,23 +18,26 @@ App::gh::Command::Drop - drop a repository.
 
 sub run {
     my ($self,$repo) = @_;
-    my $auth = get_github_auth();
+
+	my $gh_id = App::gh->config->github_id();
+	my $gh_token = App::gh->config->github_token();
 
     $repo =~ s{::}{-}g;
 
-    unless( $auth ) {
+    unless( $gh_id && $gh_token ) {
         die "Github authtoken not found. Can not fork repository.\n";
     }
+
     die unless $repo;
 
     print "Deleting @{[ $auth->{user} ]}/@{[ $repo ]}\n";
 
     # repos/delete/:user/:repo
-    my $uri = sprintf( qq{repos/delete/%s/%s?login=%s&token=%s}, $auth->{user}, $repo, $auth->{user}, $auth->{token} );
-    my $ret = api_request($uri);
+    my $uri = sprintf( qq{repos/delete/%s/%s?login=%s&token=%s}, $gh_id , $repo, $gh_id , $gh_token );
+    my $ret = App::gh->api->request($uri);
     my $delete_token = $ret->{delete_token};
     $uri .= '&delete_token=' . $delete_token;
-    $ret = api_request($uri);
+    $ret = App::gh->api->request($uri);
     print $ret->{status} , "\n";
     return;
 }
